/****************************************************************
 *    	Histogram Viewer for Quasi-Elastic e-p & e-n Q^2  		*
 *		  runs from output of epenQ2v6.groovy					*	
 *		Version 1 | 18-jul-12									*
 *   	Alexander Balsamo: alexander.balsamo@richmond.edu  		*
 *		Coatjava Version: 	5a.3.3	| Released: 18-jun-01  		*
 * **************************************************************
 ~																~
 * **************************************************************
 *	How to Run: 												*
 *	~$ run-groovy epenQ2HistViewer.groovy yourHistEpenFile.hipo	*
 *																*
 * This will display Q^2 histograms for reconstructed data and	*
 * 	ratio plots for reconstructed and generated events. 		*
 * 	Calculated reconstructed and generated ratios should appear	*
 *	within the terminal window.									*
 ****************************************************************/

// imports for Histograms and TCanvas
import org.jlab.groot.data.*;
import org.jlab.groot.ui.*;

// first argument is file name
String inputFile = args[0];

// recreate the histFile Directory
TDirectory histFile = new TDirectory();
histFile.readFile(inputFile);

// get the histograms from the histFile Directory
H1F q2Raw = (H1F)histFile.getObject("epenQ2","q2Raw");
H1F q2Acceptance = (H1F)histFile.getObject("epenQ2","q2Acceptance");
H1F q2ep = (H1F)histFile.getObject("epenQ2","q2ep");
H1F q2epThetaPq = (H1F)histFile.getObject("epenQ2","q2epThetaPq");
H1F q2en = (H1F)histFile.getObject("epenQ2","q2en");
H1F q2enThetaPq = (H1F)histFile.getObject("epenQ2","q2enThetaPq");
H1F q2epSim = (H1F)histFile.getObject("epenQ2","q2epSim");
H1F q2enSim = (H1F)histFile.getObject("epenQ2","q2enSim");

// fill ratio plot for reconstructed events
H1F recRatio = H1F.divide(q2enThetaPq,q2epThetaPq)
recRatio.setTitle("Reconstructed e-n/e-p Q^2 Ratio");
recRatio.setTitleX("Q^2");
histFile.getDir("epenQ2").add("recRatio",recRatio);

// fill ratio plot for generated events
H1F genRatio = H1F.divide(q2enSim,q2epSim)
genRatio.setTitle("Generated e-n/e-p Q^2 Ratio");
genRatio.setTitleX("Q^2");
histFile.getDir("epenQ2").add("genRatio",genRatio);

// get the ratio for reconstructed events
float weight;
float wT;
float total;
float average;
float[] ratData = recRatio.getData();
float[] ratError = recRatio.getDataError();

for(int i = 0; i < ratData.length; i++){
	if(ratData[i] != 0){
		weight = 1/Math.pow(ratError[i],2);
		wT = weight + wT;
		total = (weight*ratData[i]) + total;
	}
}
average = total/wT;
System.out.println("\nReconstructed Ratio 	= " + average);

// get the ratio for generated events
float genWeight;
float genWT;
float genTotal;
float genAverage;
float[] genRatData = genRatio.getData();
float[] genRatError = genRatio.getDataError();

for(int i = 0; i < genRatData.length; i++){
	if(genRatData[i] != 0){
		genWeight = 1/Math.pow(genRatError[i],2);
		genWT = genWeight + genWT;
		genTotal = (genWeight*genRatData[i]) + genTotal;
	}
}
genAverage = genTotal/genWT;
System.out.println("Generated Ratio 	= " + genAverage);

// Generate Canvas for Histograms *******************************************************************************
TCanvas q2 = new TCanvas("Q^2 Comparisons",1300,700); // TCanvas("Name of window",x-pixels,y-pixels)
q2.divide(4,2); // (1x1) histogram

q2.cd(0); // draw first
q2.draw(q2Raw);

q2.cd(1);
q2.draw(q2Acceptance);

q2.cd(2);
q2.draw(q2ep);

q2.cd(6);
q2.draw(q2epThetaPq);

q2.cd(3);
q2.draw(q2en);

q2.cd(7);
q2.draw(q2enThetaPq);

TCanvas ratioh = new TCanvas("Ratio",800,1200);
ratioh.divide(1,2);

ratioh.cd(0);
ratioh.draw(recRatio.getGraph());

ratioh.cd(1);
ratioh.draw(genRatio.getGraph());